@@ -731,6 +731,68 @@ def get_double_bytes(value, order=""):
         return
 
 
+# endregion
+# region 位功能
+# 获得对应bit位的值
+def get_bit_from_byte(target_byte, bit_index):
+    """ 获得int8对应bytearray
+    :param1 target_byte: 所要获取的对象所在字节，byte
+    :param2 bit_index: 所要获取的对象所在字节位置，int类型
+    :return: 对应bit结果, 0或1
+    """
+    try:
+        if (type(target_byte) != int) or (target_byte > 255 or target_byte < 0):
+            print("type of target_byte or target_byte is error, do not get bit")
+            return
+        if (type(bit_index) != int) or (bit_index > 7 or bit_index < 0):
+            print("type of bit_index or bit_index is error, do not get bit")
+            return
+        return (target_byte >> bit_index) & 0x01
+    except Exception as e:
+        print(e)
+        return
+
+
+# 修改对应bit位的值
+def add_bit_to_byte(target_byte, bit_index, bit_value):
+    """ 获得int8对应bytearray
+    :param1 target_byte: 所要获取的对象所在字节，byte
+    :param2 bit_index: 所要获取的对象所在字节位置，int类型
+    :param3 bit_value: 所要获取的对象所在字节位置，int类型
+    :return: 对应byte结果
+    """
+    try:
+        if (type(target_byte) != int) or (target_byte > 255 or target_byte < 0):
+            print("type of target_byte or target_byte is error, do not get bit")
+            return
+        if (type(bit_index) != int) or (bit_index > 7 or bit_index < 0):
+            print("type of bit_index or bit_index is error, do not get bit")
+            return
+        if (type(bit_value) != int) or (bit_value > 1 or bit_value < 0):
+            print("type of bit_value or bit_value is error, do not get bit")
+            return
+        return target_byte | (bit_value << bit_index)
+    except Exception as e:
+        print(e)
+        return
+
+
+# 返回byte对应的bit二进制字符串
+def get_bit_string_from_byte(target_byte):
+    """ 返回byte对应的bit二进制字符串
+    :param1 target_byte: 所要获取的对象字节，byte
+    :return: 对应bit字符串
+    """
+    try:
+        if (type(target_byte) != int) or (target_byte > 255 or target_byte < 0):
+            print("type of target_byte or target_byte is error, do not get bit")
+            return
+        return format(0x0100 + result, 'b')[1:]
+    except Exception as e:
+        print(e)
+        return
+
+
 # endregion
 # region crc16_modbus功能
 # bytes加入crc16_modbus
@@ -819,11 +881,13 @@ def find_head(bytes_data, head_data):
 
 # 测试代码
 if __name__ == '__main__':
-    input_data = [0x01, 0x03, 0x00, 0x01, 0x00, 0x01]
+    input_data = [0xF3, 0x03, 0x00, 0x01, 0x00, 0x01]
     print("*" * 50)
-    print(bytes_to_hex_str(input_data))
-    print(bytes_to_hex_str(crc16_modbus_bytes(input_data)))
-    print(crc16_modbus_int16(input_data))
+    # for x in range(8):
+    #     print(get_bit_from_byte(0xf3, x))
+    result = 0
+    result = add_bit_to_byte(result, 2, 1)
+    # 二进制显示result，8位
+    print(get_bit_string_from_byte(result))
     print("*" * 50)
-    print(bytes_to_hex_str(bytes_add_crc16_modbus(input_data, front="low")))
     pass
